@import "../../../css/_mixins.scss";
@import "../../../css/_trx_addons.vars.scss";

//@mixin sc_countdown--sm() {
@media #{$media_sm} {
    /* Countdown */
	.sc_countdown_default .sc_countdown_digits, .sc_countdown_default .sc_countdown_separator {
		font-size: 2.5em;
	}
}

//@mixin sc_countdown--xs() {
@media #{$media_xs} {
    /* Countdown */
	.sc_countdown_default .sc_countdown_digits, .sc_countdown_default .sc_countdown_separator {
		font-size: 1.5em;
	}
	.sc_countdown_circle .sc_countdown_digits, .sc_countdown_circle .sc_countdown_separator {
		font-size: 1.4em;
	}
	.sc_countdown .sc_countdown_separator {
		margin:0 5px;
	}
	.sc_countdown_circle .sc_countdown_digits {
		border-width: 3px;
	}
}